@@ -41,6 +41,7 @@ from dulwich.repo import (
     Repo,
     MemoryRepo,
     check_user_identity,
+    UnsupportedVersion,
     )
 from dulwich.tests import (
     TestCase,
@@ -207,6 +208,7 @@ class RepositoryRootTests(TestCase):
     def test_contains_object(self):
         r = self.open_repo('a.git')
         self.assertTrue(r.head() in r)
+        self.assertFalse(b"z" * 40 in r)
 
     def test_contains_ref(self):
         r = self.open_repo('a.git')
@@ -251,6 +253,17 @@ class RepositoryRootTests(TestCase):
         r = self.open_repo('a.git')
         self.assertEqual(r.get_peeled(b'HEAD'), r.head())
 
+    def test_get_parents(self):
+        r = self.open_repo('a.git')
+        self.assertEqual(
+            [b'2a72d929692c41d8554c07f6301757ba18a65d91'],
+            r.get_parents(b'a90fa2d900a17e99b433217e988c4eb4a2e9a097'))
+        r.update_shallow(
+                [b'a90fa2d900a17e99b433217e988c4eb4a2e9a097'],
+                None)
+        self.assertEqual(
+            [], r.get_parents(b'a90fa2d900a17e99b433217e988c4eb4a2e9a097'))
+
     def test_get_walker(self):
         r = self.open_repo('a.git')
         # include defaults to [r.head()]
@@ -860,6 +873,13 @@ class BuildRepoRootTests(TestCase):
         r = Repo(self._repo_dir)
         self.assertEqual(r.object_store.loose_compression_level, 4)
 
+    def test_repositoryformatversion(self):
+        r = self._repo
+        c = r.get_config()
+        c.set(('core',), 'repositoryformatversion', '2')
+        c.write_to_path()
+        self.assertRaises(UnsupportedVersion, Repo, self._repo_dir)
+
     def test_commit_encoding_from_config(self):
         r = self._repo
         c = r.get_config()
